@@ -1,4 +1,4 @@
-package Pcore::Nginx v1.2.1;
+package Pcore::Nginx v1.2.2;
 
 use Pcore -dist, -class, -try;
 
@@ -6,6 +6,8 @@ has data_dir     => ( is => 'ro',   isa => Str, default => "$ENV->{DATA_DIR}" );
 has nginx_bin    => ( is => 'lazy', isa => Str, default => 'nginx' );
 has nginx_prefix => ( is => 'lazy', isa => Str, default => '/etc/nginx/' );
 
+has user => ( is => 'ro', isa => Maybe [Str] );    # nginx workers user
+
 has conf_dir  => ( is => 'lazy', isa => Str,    init_arg => undef );
 has vhost_dir => ( is => 'lazy', isa => Str,    init_arg => undef );
 has proc      => ( is => 'ro',   isa => Object, init_arg => undef );
@@ -33,6 +35,7 @@ sub _build_vhost_dir ($self) {
 
 sub run ($self) {
     my $params = {
+        user               => $self->user,
         pid                => $self->conf_dir . 'nginx.pid',
         mime_types         => $self->conf_dir . 'mime.types',
         error_log          => $self->data_dir . 'nginx-error.log',
@@ -85,7 +88,7 @@ sub is_vhost_exists ( $self, $name ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 13                   | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 15                   | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
